@@ -6,7 +6,7 @@ context ("Creating backwards linkages")
 de_coeff <- input_coefficient_matrix_create( iotable_get(), digits = 4)
 
 I <- leontieff_inverse_create ( de_coeff )
-I4 <- sapply ( I[, 2:ncol(I)], function (x) round(x, 4))
+I4 <- sapply ( I[, 2:ncol(I)], function (x) round(x, 4)) # sapply because we do not know the dimensions
 I4 <- cbind(I[,1], I4)
 I4 <- as.data.frame ( I4)
 for (i in 2:ncol(I4)) I4[,i] <- as.numeric(as.character(I4[,i]))
